@@ -423,17 +423,20 @@ sub get_services_checks {
     if($hostobj && $hostobj->{'conf'}->{'_AGENT_CONFIG'}) {
         $settings = decode_json($hostobj->{'conf'}->{'_AGENT_CONFIG'});
     }
-    $checks = _extract_checks(
-                    $c,
-                    $data->{'inventory'},
-                    $hostname,
-                    $password,
-                    $cli_opts,
-                    $section,
-                    $mode,
-                    $options // $settings->{'options'} // {},
-                    $tags,
-                ) if $data->{'inventory'};
+    if($data->{'inventory'}) {
+        $data->{'inventory'}->{'_snclient'} = $data->{'snclient'} if $data->{'snclient'};
+        $checks = _extract_checks(
+                        $c,
+                        $data->{'inventory'},
+                        $hostname,
+                        $password,
+                        $cli_opts,
+                        $section,
+                        $mode,
+                        $options // $settings->{'options'} // {},
+                        $tags,
+                    );
+    }
 
     return($checks);
 }
@@ -527,6 +530,24 @@ sub get_inventory {
     die($output || 'no output from inventory scan command');
 }
 
+##########################################################
+
+=head2 has_agent_min_version
+
+    has_agent_min_version($inventory, $version)
+
+returns true if inventory contains snclient with version greater or equal to the supplied version
+
+=cut
+sub has_agent_min_version {
+    my($inventory, $min_version) = @_;
+    return unless $inventory;
+    return unless $inventory->{'_snclient'};
+    return unless $inventory->{'_snclient'}->{'version'};
+
+    return(Thruk::Utils::version_compare($inventory->{'_snclient'}->{'version'}, $min_version));
+}
+
 ##########################################################
 sub _extract_checks {
     my($c, $inventory, $hostname, $password, $cli_opts, $section, $mode, $options, $tags) = @_;
@@ -615,6 +636,9 @@ sub _extract_checks {
 
         $chk->{'name'} =~ s|[`~!\$%^&*\|'"<>?,()=]*||gmx; # remove nasty chars from object name
         $chk->{'name'} =~ s|\\$||gmx; # remove trailing slashes from service names, ex.: in windows drives
+
+        $command               = Thruk::Base::trim_whitespace($command);
+        $current_args          = Thruk::Base::trim_whitespace($current_args);
         $chk->{'current_args'} = $current_args;
 
         $chk->{'svc_conf'} = {
